import 'package:flutter/material.dart';
import 'package:flutter_pickers/pickers.dart';
import 'package:flutter_pickers/time_picker/model/date_mode.dart';
import 'package:flutter_pickers/time_picker/model/pduration.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'bruno_calendar.dart';

class TLCalendar extends StatefulWidget {
  const TLCalendar(
    this.title, {
    Key? key,
    this.style,
    this.padding,
    this.startTime,
    this.endTime,
    this.selectMode = SelectMode.single,
    this.dateChange,
    this.rangeDateChange,
    this.minDate,
    this.maxDate,
  }) : super(key: key);

  @override
  State<TLCalendar> createState() => _TLCalendarState();

  final String title;
  final TextStyle? style;
  final EdgeInsetsGeometry? padding;
  final DateTime? startTime;
  final DateTime? endTime;
  final SelectMode selectMode;
  final Function(DateTime datetime)? dateChange;
  final Function(DateTimeRange dateTimeRange)? rangeDateChange;
  final DateTime? minDate;

  /// 日历日期选择范围最大值
  ///
  /// 默认 `DateTime(2100)`
  final DateTime? maxDate;
}

GlobalKey<_TLCalendarState> _calendarKey = GlobalKey<_TLCalendarState>();
GlobalKey<_TLCalendarState> get calendarKey => _calendarKey;

class _TLCalendarState extends State<TLCalendar> {
  //

  // dateChangeChoiceSure() {
  //   if (startTime != null) {
  //     widget.dateChange?.call(startTime!);
  //   }
  // }
  // rangeDateChoiceSure() {
  //   if (startTime != null && endTime != null) {
  //     widget.rangeDateChange?.call(DateTimeRange(start: startTime!, end: endTime!));
  //   }
  // }

  dateReset() {
    setState(() {
      startTime = widget.startTime;
      endTime = widget.endTime;
      isReset = true;
    });
    widget.dateChange?.call(widget.startTime ?? DateTime.now());
  }

  @override
  void initState() {
    super.initState();
    startTime = widget.startTime;
    endTime = widget.endTime;
    isReset = true;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: widget.padding ?? EdgeInsets.zero,
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          widget.title.isEmpty
              ? const SizedBox.shrink()
              : Padding(
                  padding: EdgeInsets.symmetric(
                    vertical: 8.h,
                  ),
                  child: Text(
                    widget.title,
                    style: widget.style ??
                        TextStyle(
                          color: Colors.black,
                          fontSize: 16.sp,
                          fontWeight: FontWeight.w500,
                        ),
                  ),
                ),
          TBrnCalendarView(
            key: isReset ? key1 : key2,
            displayMode: DisplayMode.month,
            selectMode: widget.selectMode,
            initStartSelectedDate: startTime,
            initEndSelectedDate: endTime,
            minDate: widget.minDate,
            maxDate: widget.maxDate,
            dateChange: (DateTime datetime) {
              setState(() {
                startTime = datetime;
                isReset = false;
              });
              widget.dateChange?.call(datetime);
            },
            rangeDateChange: (DateTimeRange dateTimeRange) {
              setState(() {
                startTime = dateTimeRange.start;
                endTime = dateTimeRange.end;
                isReset = false;
              });
              widget.rangeDateChange?.call(dateTimeRange);
            },
          ),
        ],
      ),
    );
  }

  DateTime? startTime;
  DateTime? endTime;
  bool isReset = true;
  LocalKey key1 = UniqueKey();
  LocalKey key2 = UniqueKey();
}

class TLPickers {
  static void showDatePicker(BuildContext context, {DateMode mode = DateMode.YMDHMS, PDuration? maxDate, String normalTime = "", Function(String time)? onConfirm}) {
    Pickers.showDatePicker(
      context,
      selectDate: PDuration.parse(DateTime.tryParse(normalTime) ?? DateTime.now()),
      mode: mode,
      maxDate: maxDate,
      onConfirm: (PDuration p) {
        String time = "";
        if (mode == DateMode.YMDHMS) {
          time = p.year.toString() +
              "-" +
              p.month.toString().padLeft(2, "0") +
              "-" +
              p.day.toString().padLeft(2, "0") +
              " " +
              p.hour.toString().padLeft(2, "0") +
              ":" +
              p.minute.toString().padLeft(2, "0") +
              ":" +
              p.second.toString().padLeft(2, "0");
        } else if (mode == DateMode.YMDHM) {
          time = p.year.toString() +
              "-" +
              p.month.toString().padLeft(2, "0") +
              "-" +
              p.day.toString().padLeft(2, "0") +
              " " +
              p.hour.toString().padLeft(2, "0") +
              ":" +
              p.minute.toString().padLeft(2, "0");
        } else if (mode == DateMode.YMD) {
          time = p.year.toString() + "-" + p.month.toString().padLeft(2, "0") + "-" + p.day.toString().padLeft(2, "0");
        }
        onConfirm?.call(time);
      },
    );
  }

  static void showAddressPicker(BuildContext context, {String normalAddress = "", Function(String address)? onConfirm}) {
    if (normalAddress.isEmpty) {
      normalAddress = '湖北省/武汉市';
    }
    // Pickers.showAddressPicker(
    //   context,
    //   initProvince: normalAddress.split('/').first,
    //   initCity: normalAddress.split('/').last,
    //   addAllItem: false,
    //   onConfirm: (String initProvince, String initCity, String? initTown) {
    //     onConfirm?.call([initProvince, initCity].join('/'));
    //   },
    // );
    Map<String, List<String>> multiData = {};
    for (Map typeItem in cityOptions) {
      multiData[typeItem["value"]] = typeItem["children"].map<String>((e) => e["value"] as String).toList();
    }
    Pickers.showMultiLinkPicker(
      context,
      data: multiData,
      selectData: [normalAddress.split('/').first, normalAddress.split('/').last],
      columeNum: 2,
      onConfirm: (list1, list2) {
        onConfirm?.call([list1[0], list1[1]].join('/'));
      },
    );
  }

  static String getAddress(String plateNo) {
    for (Map typeItem in cityOptions) {
      for (Map city in typeItem["children"]) {
        if (plateNo.contains(city["code"])) {
          return "${typeItem["value"]}/${city["value"]}";
        }
      }
    }
    return "";
  }
}

const cityOptions = [
  {
    "children": [
      {"label": "武汉市", "value": "武汉市", "Pcode": "鄂", "code": "鄂A"},
      {"label": "黄石市", "value": "黄石市", "Pcode": "鄂", "code": "鄂B"},
      {"label": "十堰市", "value": "十堰市", "Pcode": "鄂", "code": "鄂C"},
      {"label": "宜昌市", "value": "宜昌市", "Pcode": "鄂", "code": "鄂E"},
      {"label": "襄阳市", "value": "襄阳市", "Pcode": "鄂", "code": "鄂F"},
      {"label": "鄂州市", "value": "鄂州市", "Pcode": "鄂", "code": "鄂G"},
      {"label": "荆门市", "value": "荆门市", "Pcode": "鄂", "code": "鄂H"},
      {"label": "孝感市", "value": "孝感市", "Pcode": "鄂", "code": "鄂K"},
      {"label": "荆州市", "value": "荆州市", "Pcode": "鄂", "code": "鄂D"},
      {"label": "黄冈市", "value": "黄冈市", "Pcode": "鄂", "code": "鄂J"},
      {"label": "咸宁市", "value": "咸宁市", "Pcode": "鄂", "code": "鄂L"},
      {"label": "随州市", "value": "随州市", "Pcode": "鄂", "code": "鄂S"},
      {"label": "恩施土家族苗族自治州", "value": "恩施土家族苗族自治州", "Pcode": "鄂", "code": "鄂Q"},
      {"label": "仙桃市", "value": "仙桃市", "Pcode": "鄂", "code": "鄂M"},
      {"label": "潜江市", "value": "潜江市", "Pcode": "鄂", "code": "鄂N"},
      {"label": "天门市", "value": "天门市", "Pcode": "鄂", "code": "鄂R"},
      {"label": "神农架林区", "value": "神农架林区", "Pcode": "鄂", "code": "鄂P"}
    ],
    "label": "湖北省",
    "value": "湖北省",
    "Pcode": "鄂"
  },
  {
    "children": [
      {"label": "东城区", "value": "东城区", "Pcode": "京", "code": "京A"},
      {"label": "西城区", "value": "西城区", "Pcode": "京", "code": "京B"},
      {"label": "朝阳区", "value": "朝阳区", "Pcode": "京", "code": "京C"},
      {"label": "丰台区", "value": "丰台区", "Pcode": "京", "code": "京D"},
      {"label": "石景山区", "value": "石景山区", "Pcode": "京", "code": "京E"},
      {"label": "海淀区", "value": "海淀区", "Pcode": "京", "code": "京F"},
      {"label": "门头沟区", "value": "门头沟区", "Pcode": "京", "code": "京G"},
      {"label": "房山区", "value": "房山区", "Pcode": "京", "code": "京H"},
      {"label": "通州区", "value": "通州区", "Pcode": "京", "code": "京J"},
      {"label": "顺义区", "value": "顺义区", "Pcode": "京", "code": "京K"},
      {"label": "昌平区", "value": "昌平区", "Pcode": "京", "code": "京L"},
      {"label": "大兴区", "value": "大兴区", "Pcode": "京", "code": "京M"},
      {"label": "怀柔区", "value": "怀柔区", "Pcode": "京", "code": "京N"},
      {"label": "平谷区", "value": "平谷区", "Pcode": "京", "code": "京P"},
      {"label": "密云区", "value": "密云区", "Pcode": "京", "code": "京Q"},
      {"label": "延庆区", "value": "延庆区", "Pcode": "京", "code": "京Y"}
    ],
    "label": "北京市",
    "value": "北京市",
    "Pcode": "京"
  },
  {
    "children": [
      {"label": "黄浦区", "value": "黄浦区", "Pcode": "沪", "code": "沪A"},
      {"label": "徐汇区", "value": "徐汇区", "Pcode": "沪", "code": "沪B"},
      {"label": "长宁区", "value": "长宁区", "Pcode": "沪", "code": "沪C"},
      {"label": "静安区", "value": "静安区", "Pcode": "沪", "code": "沪D"},
      {"label": "普陀区", "value": "普陀区", "Pcode": "沪", "code": "沪E"},
      {"label": "虹口区", "value": "虹口区", "Pcode": "沪", "code": "沪F"},
      {"label": "杨浦区", "value": "杨浦区", "Pcode": "沪", "code": "沪G"},
      {"label": "闵行区", "value": "闵行区", "Pcode": "沪", "code": "沪H"},
      {"label": "宝山区", "value": "宝山区", "Pcode": "沪", "code": "沪J"},
      {"label": "嘉定区", "value": "嘉定区", "Pcode": "沪", "code": "沪K"},
      {"label": "浦东新区", "value": "浦东新区", "Pcode": "沪", "code": "沪L"},
      {"label": "金山区", "value": "金山区", "Pcode": "沪", "code": "沪M"},
      {"label": "松江区", "value": "松江区", "Pcode": "沪", "code": "沪N"},
      {"label": "青浦区", "value": "青浦区", "Pcode": "沪", "code": "沪D"},
      {"label": "奉贤区", "value": "奉贤区", "Pcode": "沪", "code": "沪E"},
      {"label": "崇明区", "value": "崇明区", "Pcode": "沪", "code": "沪F"}
    ],
    "label": "上海市",
    "value": "上海市",
    "Pcode": "沪"
  },
  {
    "children": [
      {"label": "昆明市", "value": "昆明市", "Pcode": "云", "code": "云A"},
      {"label": "曲靖市", "value": "曲靖市", "Pcode": "云", "code": "云D"},
      {"label": "玉溪市", "value": "玉溪市", "Pcode": "云", "code": "云F"},
      {"label": "保山市", "value": "保山市", "Pcode": "云", "code": "云M"},
      {"label": "昭通市", "value": "昭通市", "Pcode": "云", "code": "云C"},
      {"label": "丽江市", "value": "丽江市", "Pcode": "云", "code": "云P"},
      {"label": "普洱市", "value": "普洱市", "Pcode": "云", "code": "云J"},
      {"label": "临沧市", "value": "临沧市", "Pcode": "云", "code": "云S"},
      {"label": "楚雄彝族自治州", "value": "楚雄彝族自治州", "Pcode": "云", "code": "云E"},
      {"label": "红河哈尼族彝族自治州", "value": "红河哈尼族彝族自治州", "Pcode": "云", "code": "云G"},
      {"label": "文山壮族苗族自治州", "value": "文山壮族苗族自治州", "Pcode": "云", "code": "云H"},
      {"label": "西双版纳傣族自治州", "value": "西双版纳傣族自治州", "Pcode": "云", "code": "云K"},
      {"label": "大理白族自治州", "value": "大理白族自治州", "Pcode": "云", "code": "云L"},
      {"label": "德宏傣族景颇族自治州", "value": "德宏傣族景颇族自治州", "Pcode": "云", "code": "云N"},
      {"label": "怒江傈僳族自治州", "value": "怒江傈僳族自治州", "Pcode": "云", "code": "云Q"},
      {"label": "迪庆藏族自治州", "value": "迪庆藏族自治州", "Pcode": "云", "code": "云R"}
    ],
    "label": "云南省",
    "value": "云南省",
    "Pcode": "云"
  },
  {
    "children": [
      {"label": "呼和浩特市", "value": "呼和浩特市", "Pcode": "蒙", "code": "蒙A"},
      {"label": "包头市", "value": "包头市", "Pcode": "蒙", "code": "蒙B"},
      {"label": "乌海市", "value": "乌海市", "Pcode": "蒙", "code": "蒙C"},
      {"label": "赤峰市", "value": "赤峰市", "Pcode": "蒙", "code": "蒙D"},
      {"label": "通辽市", "value": "通辽市", "Pcode": "蒙", "code": "蒙G"},
      {"label": "鄂尔多斯市", "value": "鄂尔多斯市", "Pcode": "蒙", "code": "蒙K"},
      {"label": "呼伦贝尔市", "value": "呼伦贝尔市", "Pcode": "蒙", "code": "蒙E"},
      {"label": "巴彦淖尔市", "value": "巴彦淖尔市", "Pcode": "蒙", "code": "蒙L"},
      {"label": "乌兰察布市", "value": "乌兰察布市", "Pcode": "蒙", "code": "蒙J"},
      {"label": "兴安盟", "value": "兴安盟", "Pcode": "蒙", "code": "蒙F"},
      {"label": "锡林郭勒盟", "value": "锡林郭勒盟", "Pcode": "蒙", "code": "蒙H"},
      {"label": "阿拉善盟", "value": "阿拉善盟", "Pcode": "蒙", "code": "蒙M"}
    ],
    "label": "内蒙古自治区",
    "value": "内蒙古自治区",
    "Pcode": "蒙"
  },
  {
    "children": [
      {"label": "长春市", "value": "长春市", "Pcode": "吉", "code": "吉A"},
      {"label": "吉林市", "value": "吉林市", "Pcode": "吉", "code": "吉B"},
      {"label": "四平市", "value": "四平市", "Pcode": "吉", "code": "吉C"},
      {"label": "辽源市", "value": "辽源市", "Pcode": "吉", "code": "吉D"},
      {"label": "通化市", "value": "通化市", "Pcode": "吉", "code": "吉E"},
      {"label": "白山市", "value": "白山市", "Pcode": "吉", "code": "吉F"},
      {"label": "松原市", "value": "松原市", "Pcode": "吉", "code": "吉J"},
      {"label": "白城市", "value": "白城市", "Pcode": "吉", "code": "吉G"},
      {"label": "延边朝鲜族自治州", "value": "延边朝鲜族自治州", "Pcode": "吉", "code": "吉H"}
    ],
    "label": "吉林省",
    "value": "吉林省",
    "Pcode": "吉"
  },
  {
    "children": [
      {"label": "成都市", "value": "成都市", "Pcode": "川", "code": "川A"},
      {"label": "自贡市", "value": "自贡市", "Pcode": "川", "code": "川C"},
      {"label": "攀枝花市", "value": "攀枝花市", "Pcode": "川", "code": "川D"},
      {"label": "泸州市", "value": "泸州市", "Pcode": "川", "code": "川E"},
      {"label": "德阳市", "value": "德阳市", "Pcode": "川", "code": "川F"},
      {"label": "绵阳市", "value": "绵阳市", "Pcode": "川", "code": "川B"},
      {"label": "广元市", "value": "广元市", "Pcode": "川", "code": "川H"},
      {"label": "遂宁市", "value": "遂宁市", "Pcode": "川", "code": "川J"},
      {"label": "内江市", "value": "内江市", "Pcode": "川", "code": "川K"},
      {"label": "乐山市", "value": "乐山市", "Pcode": "川", "code": "川L"},
      {"label": "南充市", "value": "南充市", "Pcode": "川", "code": "川R"},
      {"label": "眉山市", "value": "眉山市", "Pcode": "川", "code": "川Z"},
      {"label": "宜宾市", "value": "宜宾市", "Pcode": "川", "code": "川Q"},
      {"label": "广安市", "value": "广安市", "Pcode": "川", "code": "川X"},
      {"label": "达州市", "value": "达州市", "Pcode": "川", "code": "川S"},
      {"label": "雅安市", "value": "雅安市", "Pcode": "川", "code": "川T"},
      {"label": "巴中市", "value": "巴中市", "Pcode": "川", "code": "川Y"},
      {"label": "资阳市", "value": "资阳市", "Pcode": "川", "code": "川M"},
      {"label": "阿坝藏族羌族自治州", "value": "阿坝藏族羌族自治州", "Pcode": "川", "code": "川U"},
      {"label": "甘孜藏族自治州", "value": "甘孜藏族自治州", "Pcode": "川", "code": "川V"},
      {"label": "凉山彝族自治州", "value": "凉山彝族自治州", "Pcode": "川", "code": "川W"}
    ],
    "label": "四川省",
    "value": "四川省",
    "Pcode": "川"
  },
  {
    "children": [
      {"label": "和平区", "value": "和平区", "Pcode": "津", "code": "津A"},
      {"label": "河东区", "value": "河东区", "Pcode": "津", "code": "津B"},
      {"label": "河西区", "value": "河西区", "Pcode": "津", "code": "津D"},
      {"label": "南开区", "value": "南开区", "Pcode": "津", "code": "津E"},
      {"label": "河北区", "value": "河北区", "Pcode": "津", "code": "津F"},
      {"label": "红桥区", "value": "红桥区", "Pcode": "津", "code": "津G"},
      {"label": "东丽区", "value": "东丽区", "Pcode": "津", "code": "津H"},
      {"label": "西青区", "value": "西青区", "Pcode": "津", "code": "津J"},
      {"label": "津南区", "value": "津南区", "Pcode": "津", "code": "津K"},
      {"label": "北辰区", "value": "北辰区", "Pcode": "津", "code": "津L"},
      {"label": "武清区", "value": "武清区", "Pcode": "津", "code": "津N"},
      {"label": "宝坻区", "value": "宝坻区", "Pcode": "津", "code": "津P"},
      {"label": "滨海新区", "value": "滨海新区", "Pcode": "津", "code": "津Q"},
      {"label": "宁河区", "value": "宁河区", "Pcode": "津", "code": "津R"},
      {"label": "静海区", "value": "静海区", "Pcode": "津", "code": "津A"},
      {"label": "蓟州区", "value": "蓟州区", "Pcode": "津", "code": "津B"}
    ],
    "label": "天津市",
    "value": "天津市",
    "Pcode": "津"
  },
  {
    "children": [
      {"label": "银川市", "value": "银川市", "Pcode": "宁", "code": "宁A"},
      {"label": "石嘴山市", "value": "石嘴山市", "Pcode": "宁", "code": "宁B"},
      {"label": "吴忠市", "value": "吴忠市", "Pcode": "宁", "code": "宁C"},
      {"label": "固原市", "value": "固原市", "Pcode": "宁", "code": "宁D"},
      {"label": "中卫市", "value": "中卫市", "Pcode": "宁", "code": "宁E"}
    ],
    "label": "宁夏回族自治区",
    "value": "宁夏回族自治区",
    "Pcode": "宁"
  },
  {
    "children": [
      {"label": "合肥市", "value": "合肥市", "Pcode": "皖", "code": "皖A"},
      {"label": "芜湖市", "value": "芜湖市", "Pcode": "皖", "code": "皖B"},
      {"label": "蚌埠市", "value": "蚌埠市", "Pcode": "皖", "code": "皖C"},
      {"label": "淮南市", "value": "淮南市", "Pcode": "皖", "code": "皖D"},
      {"label": "马鞍山市", "value": "马鞍山市", "Pcode": "皖", "code": "皖E"},
      {"label": "淮北市", "value": "淮北市", "Pcode": "皖", "code": "皖F"},
      {"label": "铜陵市", "value": "铜陵市", "Pcode": "皖", "code": "皖G"},
      {"label": "安庆市", "value": "安庆市", "Pcode": "皖", "code": "皖H"},
      {"label": "黄山市", "value": "黄山市", "Pcode": "皖", "code": "皖J"},
      {"label": "滁州市", "value": "滁州市", "Pcode": "皖", "code": "皖M"},
      {"label": "阜阳市", "value": "阜阳市", "Pcode": "皖", "code": "皖K"},
      {"label": "宿州市", "value": "宿州市", "Pcode": "皖", "code": "皖L"},
      {"label": "六安市", "value": "六安市", "Pcode": "皖", "code": "皖N"},
      {"label": "亳州市", "value": "亳州市", "Pcode": "皖", "code": "皖S"},
      {"label": "池州市", "value": "池州市", "Pcode": "皖", "code": "皖R"},
      {"label": "宣城市", "value": "宣城市", "Pcode": "皖", "code": "皖P"}
    ],
    "label": "安徽省",
    "value": "安徽省",
    "Pcode": "皖"
  },
  {
    "children": [
      {"label": "济南市", "value": "济南市", "Pcode": "鲁", "code": "鲁A"},
      {"label": "青岛市", "value": "青岛市", "Pcode": "鲁", "code": "鲁B"},
      {"label": "淄博市", "value": "淄博市", "Pcode": "鲁", "code": "鲁C"},
      {"label": "枣庄市", "value": "枣庄市", "Pcode": "鲁", "code": "鲁D"},
      {"label": "东营市", "value": "东营市", "Pcode": "鲁", "code": "鲁E"},
      {"label": "烟台市", "value": "烟台市", "Pcode": "鲁", "code": "鲁F"},
      {"label": "潍坊市", "value": "潍坊市", "Pcode": "鲁", "code": "鲁G"},
      {"label": "济宁市", "value": "济宁市", "Pcode": "鲁", "code": "鲁H"},
      {"label": "泰安市", "value": "泰安市", "Pcode": "鲁", "code": "鲁J"},
      {"label": "威海市", "value": "威海市", "Pcode": "鲁", "code": "鲁K"},
      {"label": "日照市", "value": "日照市", "Pcode": "鲁", "code": "鲁L"},
      {"label": "莱芜市", "value": "莱芜市", "Pcode": "鲁", "code": "鲁S"},
      {"label": "临沂市", "value": "临沂市", "Pcode": "鲁", "code": "鲁Q"},
      {"label": "德州市", "value": "德州市", "Pcode": "鲁", "code": "鲁N"},
      {"label": "聊城市", "value": "聊城市", "Pcode": "鲁", "code": "鲁P"},
      {"label": "滨州市", "value": "滨州市", "Pcode": "鲁", "code": "鲁M"},
      {"label": "菏泽市", "value": "菏泽市", "Pcode": "鲁", "code": "鲁R"}
    ],
    "label": "山东省",
    "value": "山东省",
    "Pcode": "鲁"
  },
  {
    "children": [
      {"label": "太原市", "value": "太原市", "Pcode": "晋", "code": "晋A"},
      {"label": "大同市", "value": "大同市", "Pcode": "晋", "code": "晋B"},
      {"label": "阳泉市", "value": "阳泉市", "Pcode": "晋", "code": "晋C"},
      {"label": "长治市", "value": "长治市", "Pcode": "晋", "code": "晋D"},
      {"label": "晋城市", "value": "晋城市", "Pcode": "晋", "code": "晋E"},
      {"label": "朔州市", "value": "朔州市", "Pcode": "晋", "code": "晋F"},
      {"label": "晋中市", "value": "晋中市", "Pcode": "晋", "code": "晋K"},
      {"label": "运城市", "value": "运城市", "Pcode": "晋", "code": "晋M"},
      {"label": "忻州市", "value": "忻州市", "Pcode": "晋", "code": "晋H"},
      {"label": "临汾市", "value": "临汾市", "Pcode": "晋", "code": "晋L"},
      {"label": "吕梁市", "value": "吕梁市", "Pcode": "晋", "code": "晋J"}
    ],
    "label": "山西省",
    "value": "山西省",
    "Pcode": "晋"
  },
  {
    "children": [
      {"label": "广州市", "value": "广州市", "Pcode": "粤", "code": "粤A"},
      {"label": "韶关市", "value": "韶关市", "Pcode": "粤", "code": "粤F"},
      {"label": "深圳市", "value": "深圳市", "Pcode": "粤", "code": "粤B"},
      {"label": "珠海市", "value": "珠海市", "Pcode": "粤", "code": "粤C"},
      {"label": "汕头市", "value": "汕头市", "Pcode": "粤", "code": "粤D"},
      {"label": "佛山市", "value": "佛山市", "Pcode": "粤", "code": "粤E"},
      {"label": "江门市", "value": "江门市", "Pcode": "粤", "code": "粤J"},
      {"label": "湛江市", "value": "湛江市", "Pcode": "粤", "code": "粤G"},
      {"label": "茂名市", "value": "茂名市", "Pcode": "粤", "code": "粤K"},
      {"label": "肇庆市", "value": "肇庆市", "Pcode": "粤", "code": "粤H"},
      {"label": "惠州市", "value": "惠州市", "Pcode": "粤", "code": "粤L"},
      {"label": "梅州市", "value": "梅州市", "Pcode": "粤", "code": "粤M"},
      {"label": "汕尾市", "value": "汕尾市", "Pcode": "粤", "code": "粤N"},
      {"label": "河源市", "value": "河源市", "Pcode": "粤", "code": "粤P"},
      {"label": "阳江市", "value": "阳江市", "Pcode": "粤", "code": "粤Q"},
      {"label": "清远市", "value": "清远市", "Pcode": "粤", "code": "粤R"},
      {"label": "东莞市", "value": "东莞市", "Pcode": "粤", "code": "粤S"},
      {"label": "中山市", "value": "中山市", "Pcode": "粤", "code": "粤T"},
      {"label": "潮州市", "value": "潮州市", "Pcode": "粤", "code": "粤U"},
      {"label": "揭阳市", "value": "揭阳市", "Pcode": "粤", "code": "粤V"},
      {"label": "云浮市", "value": "云浮市", "Pcode": "粤", "code": "粤W"}
    ],
    "label": "广东省",
    "value": "广东省",
    "Pcode": "粤"
  },
  {
    "children": [
      {"label": "南宁市", "value": "南宁市", "Pcode": "桂", "code": "桂A"},
      {"label": "柳州市", "value": "柳州市", "Pcode": "桂", "code": "桂B"},
      {"label": "桂林市", "value": "桂林市", "Pcode": "桂", "code": "桂C"},
      {"label": "梧州市", "value": "梧州市", "Pcode": "桂", "code": "桂D"},
      {"label": "北海市", "value": "北海市", "Pcode": "桂", "code": "桂E"},
      {"label": "防城港市", "value": "防城港市", "Pcode": "桂", "code": "桂P"},
      {"label": "钦州市", "value": "钦州市", "Pcode": "桂", "code": "桂N"},
      {"label": "贵港市", "value": "贵港市", "Pcode": "桂", "code": "桂R"},
      {"label": "玉林市", "value": "玉林市", "Pcode": "桂", "code": "桂K"},
      {"label": "百色市", "value": "百色市", "Pcode": "桂", "code": "桂L"},
      {"label": "贺州市", "value": "贺州市", "Pcode": "桂", "code": "桂J"},
      {"label": "河池市", "value": "河池市", "Pcode": "桂", "code": "桂M"},
      {"label": "来宾市", "value": "来宾市", "Pcode": "桂", "code": "桂G"},
      {"label": "崇左市", "value": "崇左市", "Pcode": "桂", "code": "桂F"}
    ],
    "label": "广西壮族自治区",
    "value": "广西壮族自治区",
    "Pcode": "桂"
  },
  {
    "children": [
      {"label": "乌鲁木齐市", "value": "乌鲁木齐市", "Pcode": "新", "code": "新A"},
      {"label": "克拉玛依市", "value": "克拉玛依市", "Pcode": "新", "code": "新J"},
      {"label": "吐鲁番市", "value": "吐鲁番市", "Pcode": "新", "code": "新K"},
      {"label": "哈密市", "value": "哈密市", "Pcode": "新", "code": "新L"},
      {"label": "昌吉回族自治州", "value": "昌吉回族自治州", "Pcode": "新", "code": "新B"},
      {"label": "博尔塔拉蒙古自治州", "value": "博尔塔拉蒙古自治州", "Pcode": "新", "code": "新E"},
      {"label": "巴音郭楞蒙古自治州", "value": "巴音郭楞蒙古自治州", "Pcode": "新", "code": "新M"},
      {"label": "阿克苏地区", "value": "阿克苏地区", "Pcode": "新", "code": "新N"},
      {"label": "克孜勒苏柯尔克孜自治州", "value": "克孜勒苏柯尔克孜自治州", "Pcode": "新", "code": "新P"},
      {"label": "喀什地区", "value": "喀什地区", "Pcode": "新", "code": "新Q"},
      {"label": "和田地区", "value": "和田地区", "Pcode": "新", "code": "新R"},
      {"label": "伊犁哈萨克自治州", "value": "伊犁哈萨克自治州", "Pcode": "新", "code": "新F"},
      {"label": "塔城地区", "value": "塔城地区", "Pcode": "新", "code": "新G"},
      {"label": "阿勒泰地区", "value": "阿勒泰地区", "Pcode": "新", "code": "新H"},
      {"label": "石河子市", "value": "石河子市", "Pcode": "新", "code": "新C"},
      {"label": "阿拉尔市", "value": "阿拉尔市", "Pcode": "新", "code": "新N"},
      {"label": "图木舒克市", "value": "图木舒克市", "Pcode": "新", "code": "新Q"},
      {"label": "五家渠市", "value": "五家渠市", "Pcode": "新", "code": "新B"},
      {"label": "铁门关市", "value": "铁门关市", "Pcode": "新", "code": "新M"}
    ],
    "label": "新疆维吾尔自治区",
    "value": "新疆维吾尔自治区",
    "Pcode": "新"
  },
  {
    "children": [
      {"label": "南京市", "value": "南京市", "Pcode": "苏", "code": "苏A"},
      {"label": "无锡市", "value": "无锡市", "Pcode": "苏", "code": "苏B"},
      {"label": "徐州市", "value": "徐州市", "Pcode": "苏", "code": "苏C"},
      {"label": "常州市", "value": "常州市", "Pcode": "苏", "code": "苏D"},
      {"label": "苏州市", "value": "苏州市", "Pcode": "苏", "code": "苏E"},
      {"label": "南通市", "value": "南通市", "Pcode": "苏", "code": "苏F"},
      {"label": "连云港市", "value": "连云港市", "Pcode": "苏", "code": "苏G"},
      {"label": "淮安市", "value": "淮安市", "Pcode": "苏", "code": "苏H"},
      {"label": "盐城市", "value": "盐城市", "Pcode": "苏", "code": "苏J"},
      {"label": "扬州市", "value": "扬州市", "Pcode": "苏", "code": "苏K"},
      {"label": "镇江市", "value": "镇江市", "Pcode": "苏", "code": "苏L"},
      {"label": "泰州市", "value": "泰州市", "Pcode": "苏", "code": "苏M"},
      {"label": "宿迁市", "value": "宿迁市", "Pcode": "苏", "code": "苏N"}
    ],
    "label": "江苏省",
    "value": "江苏省",
    "Pcode": "苏"
  },
  {
    "children": [
      {"label": "南昌市", "value": "南昌市", "Pcode": "赣", "code": "赣A"},
      {"label": "景德镇市", "value": "景德镇市", "Pcode": "赣", "code": "赣H"},
      {"label": "萍乡市", "value": "萍乡市", "Pcode": "赣", "code": "赣J"},
      {"label": "九江市", "value": "九江市", "Pcode": "赣", "code": "赣G"},
      {"label": "新余市", "value": "新余市", "Pcode": "赣", "code": "赣K"},
      {"label": "鹰潭市", "value": "鹰潭市", "Pcode": "赣", "code": "赣L"},
      {"label": "赣州市", "value": "赣州市", "Pcode": "赣", "code": "赣B"},
      {"label": "吉安市", "value": "吉安市", "Pcode": "赣", "code": "赣D"},
      {"label": "宜春市", "value": "宜春市", "Pcode": "赣", "code": "赣C"},
      {"label": "抚州市", "value": "抚州市", "Pcode": "赣", "code": "赣F"},
      {"label": "上饶市", "value": "上饶市", "Pcode": "赣", "code": "赣E"}
    ],
    "label": "江西省",
    "value": "江西省",
    "Pcode": "赣"
  },
  {
    "children": [
      {"label": "石家庄市", "value": "石家庄市", "Pcode": "冀", "code": "冀A"},
      {"label": "唐山市", "value": "唐山市", "Pcode": "冀", "code": "冀B"},
      {"label": "秦皇岛市", "value": "秦皇岛市", "Pcode": "冀", "code": "冀C"},
      {"label": "邯郸市", "value": "邯郸市", "Pcode": "冀", "code": "冀D"},
      {"label": "邢台市", "value": "邢台市", "Pcode": "冀", "code": "冀E"},
      {"label": "保定市", "value": "保定市", "Pcode": "冀", "code": "冀F"},
      {"label": "张家口市", "value": "张家口市", "Pcode": "冀", "code": "冀G"},
      {"label": "承德市", "value": "承德市", "Pcode": "冀", "code": "冀H"},
      {"label": "沧州市", "value": "沧州市", "Pcode": "冀", "code": "冀J"},
      {"label": "廊坊市", "value": "廊坊市", "Pcode": "冀", "code": "冀R"},
      {"label": "衡水市", "value": "衡水市", "Pcode": "冀", "code": "冀T"},
      {"label": "定州市", "value": "定州市", "Pcode": "冀", "code": "冀F"},
      {"label": "辛集市", "value": "辛集市", "Pcode": "冀", "code": "冀A"}
    ],
    "label": "河北省",
    "value": "河北省",
    "Pcode": "冀"
  },
  {
    "children": [
      {"label": "郑州市", "value": "郑州市", "Pcode": "豫", "code": "豫A"},
      {"label": "开封市", "value": "开封市", "Pcode": "豫", "code": "豫B"},
      {"label": "洛阳市", "value": "洛阳市", "Pcode": "豫", "code": "豫C"},
      {"label": "平顶山市", "value": "平顶山市", "Pcode": "豫", "code": "豫D"},
      {"label": "安阳市", "value": "安阳市", "Pcode": "豫", "code": "豫E"},
      {"label": "鹤壁市", "value": "鹤壁市", "Pcode": "豫", "code": "豫F"},
      {"label": "新乡市", "value": "新乡市", "Pcode": "豫", "code": "豫G"},
      {"label": "焦作市", "value": "焦作市", "Pcode": "豫", "code": "豫H"},
      {"label": "濮阳市", "value": "濮阳市", "Pcode": "豫", "code": "豫J"},
      {"label": "许昌市", "value": "许昌市", "Pcode": "豫", "code": "豫K"},
      {"label": "漯河市", "value": "漯河市", "Pcode": "豫", "code": "豫L"},
      {"label": "三门峡市", "value": "三门峡市", "Pcode": "豫", "code": "豫M"},
      {"label": "南阳市", "value": "南阳市", "Pcode": "豫", "code": "豫R"},
      {"label": "商丘市", "value": "商丘市", "Pcode": "豫", "code": "豫N"},
      {"label": "信阳市", "value": "信阳市", "Pcode": "豫", "code": "豫S"},
      {"label": "周口市", "value": "周口市", "Pcode": "豫", "code": "豫P"},
      {"label": "驻马店市", "value": "驻马店市", "Pcode": "豫", "code": "豫Q"},
      {"label": "济源市", "value": "济源市", "Pcode": "豫", "code": "豫U"}
    ],
    "label": "河南省",
    "value": "河南省",
    "Pcode": "豫"
  },
  {
    "children": [
      {"label": "杭州市", "value": "杭州市", "Pcode": "浙", "code": "浙A"},
      {"label": "宁波市", "value": "宁波市", "Pcode": "浙", "code": "浙B"},
      {"label": "温州市", "value": "温州市", "Pcode": "浙", "code": "浙C"},
      {"label": "嘉兴市", "value": "嘉兴市", "Pcode": "浙", "code": "浙F"},
      {"label": "湖州市", "value": "湖州市", "Pcode": "浙", "code": "浙E"},
      {"label": "绍兴市", "value": "绍兴市", "Pcode": "浙", "code": "浙D"},
      {"label": "金华市", "value": "金华市", "Pcode": "浙", "code": "浙G"},
      {"label": "衢州市", "value": "衢州市", "Pcode": "浙", "code": "浙H"},
      {"label": "舟山市", "value": "舟山市", "Pcode": "浙", "code": "浙L"},
      {"label": "台州市", "value": "台州市", "Pcode": "浙", "code": "浙J"},
      {"label": "丽水市", "value": "丽水市", "Pcode": "浙", "code": "浙K"}
    ],
    "label": "浙江省",
    "value": "浙江省",
    "Pcode": "浙"
  },
  {
    "children": [
      {"label": "海口市", "value": "海口市", "Pcode": "琼", "code": "琼A"},
      {"label": "三亚市", "value": "三亚市", "Pcode": "琼", "code": "琼B"},
      {"label": "三沙市", "value": "三沙市", "Pcode": "琼", "code": "琼C"},
      {"label": "儋州市", "value": "儋州市", "Pcode": "琼", "code": "琼F"},
      {"label": "五指山市", "value": "五指山市", "Pcode": "琼", "code": "琼D"},
      {"label": "琼海市", "value": "琼海市", "Pcode": "琼", "code": "琼C"},
      {"label": "文昌市", "value": "文昌市", "Pcode": "琼", "code": "琼C"},
      {"label": "万宁市", "value": "万宁市", "Pcode": "琼", "code": "琼C"},
      {"label": "东方市", "value": "东方市", "Pcode": "琼", "code": "D"},
      {"label": "定安县", "value": "定安县", "Pcode": "琼", "code": "琼C"},
      {"label": "屯昌县", "value": "屯昌县", "Pcode": "琼", "code": "琼C"},
      {"label": "澄迈县", "value": "澄迈县", "Pcode": "琼", "code": "琼C"},
      {"label": "临高县", "value": "临高县", "Pcode": "琼", "code": "琼C"},
      {"label": "白沙黎族自治县", "value": "白沙黎族自治县", "Pcode": "琼", "code": "琼D"},
      {"label": "昌江黎族自治县", "value": "昌江黎族自治县", "Pcode": "琼", "code": "琼D"},
      {"label": "乐东黎族自治县", "value": "乐东黎族自治县", "Pcode": "琼", "code": "琼D"},
      {"label": "陵水黎族自治县", "value": "陵水黎族自治县", "Pcode": "琼", "code": "琼D"},
      {"label": "保亭黎族苗族自治县", "value": "保亭黎族苗族自治县", "Pcode": "琼", "code": "琼D"},
      {"label": "琼中黎族苗族自治县", "value": "琼中黎族苗族自治县", "Pcode": "琼", "code": "琼D"}
    ],
    "label": "海南省",
    "value": "海南省",
    "Pcode": "琼"
  },
  {
    "children": [
      {"label": "长沙市", "value": "长沙市", "Pcode": "湘", "code": "湘A"},
      {"label": "株洲市", "value": "株洲市", "Pcode": "湘", "code": "湘B"},
      {"label": "湘潭市", "value": "湘潭市", "Pcode": "湘", "code": "湘C"},
      {"label": "衡阳市", "value": "衡阳市", "Pcode": "湘", "code": "湘D"},
      {"label": "邵阳市", "value": "邵阳市", "Pcode": "湘", "code": "湘E"},
      {"label": "岳阳市", "value": "岳阳市", "Pcode": "湘", "code": "湘F"},
      {"label": "常德市", "value": "常德市", "Pcode": "湘", "code": "湘J"},
      {"label": "张家界市", "value": "张家界市", "Pcode": "湘", "code": "湘G"},
      {"label": "益阳市", "value": "益阳市", "Pcode": "湘", "code": "湘H"},
      {"label": "郴州市", "value": "郴州市", "Pcode": "湘", "code": "湘L"},
      {"label": "永州市", "value": "永州市", "Pcode": "湘", "code": "湘M"},
      {"label": "怀化市", "value": "怀化市", "Pcode": "湘", "code": "湘N"},
      {"label": "娄底市", "value": "娄底市", "Pcode": "湘", "code": "湘K"},
      {"label": "湘西土家族苗族自治州", "value": "湘西土家族苗族自治州", "Pcode": "湘", "code": "湘U"}
    ],
    "label": "湖南省",
    "value": "湖南省",
    "Pcode": "湘"
  },
  {
    "children": [
      {"label": "兰州市", "value": "兰州市", "Pcode": "甘", "code": "甘A"},
      {"label": "嘉峪关市", "value": "嘉峪关市", "Pcode": "甘", "code": "甘B"},
      {"label": "金昌市", "value": "金昌市", "Pcode": "甘", "code": "甘C"},
      {"label": "白银市", "value": "白银市", "Pcode": "甘", "code": "甘D"},
      {"label": "天水市", "value": "天水市", "Pcode": "甘", "code": "甘E"},
      {"label": "武威市", "value": "武威市", "Pcode": "甘", "code": "甘H"},
      {"label": "张掖市", "value": "张掖市", "Pcode": "甘", "code": "甘G"},
      {"label": "平凉市", "value": "平凉市", "Pcode": "甘", "code": "甘L"},
      {"label": "酒泉市", "value": "酒泉市", "Pcode": "甘", "code": "甘F"},
      {"label": "庆阳市", "value": "庆阳市", "Pcode": "甘", "code": "甘M"},
      {"label": "定西市", "value": "定西市", "Pcode": "甘", "code": "甘J"},
      {"label": "陇南市", "value": "陇南市", "Pcode": "甘", "code": "甘K"},
      {"label": "临夏回族自治州", "value": "临夏回族自治州", "Pcode": "甘", "code": "甘N"},
      {"label": "甘南藏族自治州", "value": "甘南藏族自治州", "Pcode": "甘", "code": "甘P"}
    ],
    "label": "甘肃省",
    "value": "甘肃省",
    "Pcode": "甘"
  },
  {
    "children": [
      {"label": "福州市", "value": "福州市", "Pcode": "闽", "code": "闽A"},
      {"label": "厦门市", "value": "厦门市", "Pcode": "闽", "code": "闽D"},
      {"label": "莆田市", "value": "莆田市", "Pcode": "闽", "code": "闽B"},
      {"label": "三明市", "value": "三明市", "Pcode": "闽", "code": "闽G"},
      {"label": "泉州市", "value": "泉州市", "Pcode": "闽", "code": "闽C"},
      {"label": "漳州市", "value": "漳州市", "Pcode": "闽", "code": "闽E"},
      {"label": "南平市", "value": "南平市", "Pcode": "闽", "code": "闽H"},
      {"label": "龙岩市", "value": "龙岩市", "Pcode": "闽", "code": "闽F"},
      {"label": "宁德市", "value": "宁德市", "Pcode": "闽", "code": "闽J"}
    ],
    "label": "福建省",
    "value": "福建省",
    "Pcode": "闽"
  },
  {
    "children": [
      {"label": "拉萨市", "value": "拉萨市", "Pcode": "藏", "code": "藏A"},
      {"label": "日喀则市", "value": "日喀则市", "Pcode": "藏", "code": "藏D"},
      {"label": "昌都市", "value": "昌都市", "Pcode": "藏", "code": "藏B"},
      {"label": "林芝市", "value": "林芝市", "Pcode": "藏", "code": "藏G"},
      {"label": "山南市", "value": "山南市", "Pcode": "藏", "code": "藏C"},
      {"label": "那曲地区", "value": "那曲地区", "Pcode": "藏", "code": "藏E"},
      {"label": "阿里地区", "value": "阿里地区", "Pcode": "藏", "code": "藏F"}
    ],
    "label": "西藏自治区",
    "value": "西藏自治区",
    "Pcode": "藏"
  },
  {
    "children": [
      {"label": "贵阳市", "value": "贵阳市", "Pcode": "贵", "code": "贵A"},
      {"label": "六盘水市", "value": "六盘水市", "Pcode": "贵", "code": "贵B"},
      {"label": "遵义市", "value": "遵义市", "Pcode": "贵", "code": "贵C"},
      {"label": "安顺市", "value": "安顺市", "Pcode": "贵", "code": "贵G"},
      {"label": "毕节市", "value": "毕节市", "Pcode": "贵", "code": "贵F"},
      {"label": "铜仁市", "value": "铜仁市", "Pcode": "贵", "code": "贵D"},
      {"label": "黔西南布依族苗族自治州", "value": "黔西南布依族苗族自治州", "Pcode": "贵", "code": "贵E"},
      {"label": "黔东南苗族侗族自治州", "value": "黔东南苗族侗族自治州", "Pcode": "贵", "code": "贵H"},
      {"label": "黔南布依族苗族自治州", "value": "黔南布依族苗族自治州", "Pcode": "贵", "code": "贵J"}
    ],
    "label": "贵州省",
    "value": "贵州省",
    "Pcode": "贵"
  },
  {
    "children": [
      {"label": "沈阳市", "value": "沈阳市", "Pcode": "辽", "code": "辽A"},
      {"label": "大连市", "value": "大连市", "Pcode": "辽", "code": "辽B"},
      {"label": "鞍山市", "value": "鞍山市", "Pcode": "辽", "code": "辽C"},
      {"label": "抚顺市", "value": "抚顺市", "Pcode": "辽", "code": "辽D"},
      {"label": "本溪市", "value": "本溪市", "Pcode": "辽", "code": "辽E"},
      {"label": "丹东市", "value": "丹东市", "Pcode": "辽", "code": "辽F"},
      {"label": "锦州市", "value": "锦州市", "Pcode": "辽", "code": "辽G"},
      {"label": "营口市", "value": "营口市", "Pcode": "辽", "code": "辽H"},
      {"label": "阜新市", "value": "阜新市", "Pcode": "辽", "code": "辽J"},
      {"label": "辽阳市", "value": "辽阳市", "Pcode": "辽", "code": "辽K"},
      {"label": "盘锦市", "value": "盘锦市", "Pcode": "辽", "code": "辽L"},
      {"label": "铁岭市", "value": "铁岭市", "Pcode": "辽", "code": "辽M"},
      {"label": "朝阳市", "value": "朝阳市", "Pcode": "辽", "code": "辽N"},
      {"label": "葫芦岛市", "value": "葫芦岛市", "Pcode": "辽", "code": "辽P"}
    ],
    "label": "辽宁省",
    "value": "辽宁省",
    "Pcode": "辽"
  },
  {
    "children": [
      {"label": "万州区", "value": "万州区", "Pcode": "渝", "code": "渝F"},
      {"label": "涪陵区", "value": "涪陵区", "Pcode": "渝", "code": "渝G"},
      {"label": "渝中区", "value": "渝中区", "Pcode": "渝", "code": "渝A"},
      {"label": "大渡口区", "value": "大渡口区", "Pcode": "渝", "code": "渝B"},
      {"label": "江北区", "value": "江北区", "Pcode": "渝", "code": "渝D"},
      {"label": "沙坪坝区", "value": "沙坪坝区", "Pcode": "渝", "code": "渝F"},
      {"label": "九龙坡区", "value": "九龙坡区", "Pcode": "渝", "code": "渝G"},
      {"label": "南岸区", "value": "南岸区", "Pcode": "渝", "code": "渝H"},
      {"label": "北碚区", "value": "北碚区", "Pcode": "渝", "code": "渝A"},
      {"label": "綦江区", "value": "綦江区", "Pcode": "渝", "code": "渝A"},
      {"label": "大足区", "value": "大足区", "Pcode": "渝", "code": "渝A"},
      {"label": "渝北区", "value": "渝北区", "Pcode": "渝", "code": "渝A"},
      {"label": "巴南区", "value": "巴南区", "Pcode": "渝", "code": "渝A"},
      {"label": "黔江区", "value": "黔江区", "Pcode": "渝", "code": "渝H"},
      {"label": "长寿区", "value": "长寿区", "Pcode": "渝", "code": "渝A"},
      {"label": "江津区", "value": "江津区", "Pcode": "渝", "code": "渝A"},
      {"label": "合川区", "value": "合川区", "Pcode": "渝", "code": "渝A"},
      {"label": "永川区", "value": "永川区", "Pcode": "渝", "code": "渝C"},
      {"label": "南川区", "value": "南川区", "Pcode": "渝", "code": "渝A"},
      {"label": "璧山区", "value": "璧山区", "Pcode": "渝", "code": "渝A"},
      {"label": "铜梁区", "value": "铜梁区", "Pcode": "渝", "code": "渝A"},
      {"label": "潼南区", "value": "潼南区", "Pcode": "渝", "code": "渝A"},
      {"label": "荣昌区", "value": "荣昌区", "Pcode": "渝", "code": "渝A"},
      {"label": "开州区", "value": "开州区", "Pcode": "渝", "code": "渝A"},
      {"label": "梁平县", "value": "梁平县", "Pcode": "渝", "code": "渝A"},
      {"label": "城口县", "value": "城口县", "Pcode": "渝", "code": "渝A"},
      {"label": "丰都县", "value": "丰都县", "Pcode": "渝", "code": "渝A"},
      {"label": "垫江县", "value": "垫江县", "Pcode": "渝", "code": "渝A"},
      {"label": "武隆县", "value": "武隆县", "Pcode": "渝", "code": "渝A"},
      {"label": "忠县", "value": "忠县", "Pcode": "渝", "code": "渝A"},
      {"label": "云阳县", "value": "云阳县", "Pcode": "渝", "code": "渝A"},
      {"label": "奉节县", "value": "奉节县", "Pcode": "渝", "code": "渝A"},
      {"label": "巫山县", "value": "巫山县", "Pcode": "渝", "code": "渝A"},
      {"label": "巫溪县", "value": "巫溪县", "Pcode": "渝", "code": "渝A"},
      {"label": "石柱土家族自治县", "value": "石柱土家族自治县", "Pcode": "渝", "code": "渝A"},
      {"label": "秀山土家族苗族自治县", "value": "秀山土家族苗族自治县", "Pcode": "渝", "code": "渝A"},
      {"label": "酉阳土家族苗族自治县", "value": "酉阳土家族苗族自治县", "Pcode": "渝", "code": "渝A"},
      {"label": "彭水苗族土家族自治县", "value": "彭水苗族土家族自治县", "Pcode": "渝", "code": "渝A"}
    ],
    "label": "重庆市",
    "value": "重庆市",
    "Pcode": "渝"
  },
  {
    "children": [
      {"label": "西安市", "value": "西安市", "Pcode": "陕", "code": "陕A"},
      {"label": "铜川市", "value": "铜川市", "Pcode": "陕", "code": "陕B"},
      {"label": "宝鸡市", "value": "宝鸡市", "Pcode": "陕", "code": "陕C"},
      {"label": "咸阳市", "value": "咸阳市", "Pcode": "陕", "code": "陕D"},
      {"label": "渭南市", "value": "渭南市", "Pcode": "陕", "code": "陕E"},
      {"label": "延安市", "value": "延安市", "Pcode": "陕", "code": "陕J"},
      {"label": "汉中市", "value": "汉中市", "Pcode": "陕", "code": "陕F"},
      {"label": "榆林市", "value": "榆林市", "Pcode": "陕", "code": "陕K"},
      {"label": "安康市", "value": "安康市", "Pcode": "陕", "code": "陕G"},
      {"label": "商洛市", "value": "商洛市", "Pcode": "陕", "code": "陕H"}
    ],
    "label": "陕西省",
    "value": "陕西省",
    "Pcode": "陕"
  },
  {
    "children": [
      {"label": "西宁市", "value": "西宁市", "Pcode": "青", "code": "青A"},
      {"label": "海东市", "value": "海东市", "Pcode": "青", "code": "青B"},
      {"label": "海北藏族自治州", "value": "海北藏族自治州", "Pcode": "青", "code": "青C"},
      {"label": "黄南藏族自治州", "value": "黄南藏族自治州", "Pcode": "青", "code": "青D"},
      {"label": "海南藏族自治州", "value": "海南藏族自治州", "Pcode": "青", "code": "青E"},
      {"label": "果洛藏族自治州", "value": "果洛藏族自治州", "Pcode": "青", "code": "青F"},
      {"label": "玉树藏族自治州", "value": "玉树藏族自治州", "Pcode": "青", "code": "青G"},
      {"label": "海西蒙古族藏族自治州", "value": "海西蒙古族藏族自治州", "Pcode": "青", "code": "青H"}
    ],
    "label": "青海省",
    "value": "青海省",
    "Pcode": "青"
  },
  {
    "children": [
      {"label": "哈尔滨市", "value": "哈尔滨市", "Pcode": "黑", "code": "黑A"},
      {"label": "齐齐哈尔市", "value": "齐齐哈尔市", "Pcode": "黑", "code": "黑B"},
      {"label": "鸡西市", "value": "鸡西市", "Pcode": "黑", "code": "黑G"},
      {"label": "鹤岗市", "value": "鹤岗市", "Pcode": "黑", "code": "黑H"},
      {"label": "双鸭山市", "value": "双鸭山市", "Pcode": "黑", "code": "黑J"},
      {"label": "大庆市", "value": "大庆市", "Pcode": "黑", "code": "黑E"},
      {"label": "伊春市", "value": "伊春市", "Pcode": "黑", "code": "黑F"},
      {"label": "佳木斯市", "value": "佳木斯市", "Pcode": "黑", "code": "黑D"},
      {"label": "七台河市", "value": "七台河市", "Pcode": "黑", "code": "黑K"},
      {"label": "牡丹江市", "value": "牡丹江市", "Pcode": "黑", "code": "黑C"},
      {"label": "黑河市", "value": "黑河市", "Pcode": "黑", "code": "黑N"},
      {"label": "绥化市", "value": "绥化市", "Pcode": "黑", "code": "黑M"},
      {"label": "大兴安岭地区", "value": "大兴安岭地区", "Pcode": "黑", "code": "黑P"}
    ],
    "label": "黑龙江省",
    "value": "黑龙江省",
    "Pcode": "黑"
  },
  {
    "label": "香港",
    "value": "香港",
    "Pcode": "港",
    "children": [
      {"label": "香港", "value": "香港", "Pcode": "港", "code": "港"}
    ]
  },
  {
    "label": "澳门",
    "value": "澳门",
    "children": [
      {"label": "澳门", "value": "澳门", "Pcode": "澳", "code": "澳"}
    ],
    "Pcode": "澳"
  },
  {
    "label": "台湾省",
    "value": "台湾省",
    "Pcode": "台",
    "children": [
      {"label": "台北市", "value": "台北市", "Pcode": "台", "code": "台"},
      {"label": "新北市", "value": "新北市", "Pcode": "台", "code": "台"},
      {"label": "桃园市", "value": "桃园市", "Pcode": "台", "code": "台"},
      {"label": "台中市", "value": "台中市", "Pcode": "台", "code": "台"},
      {"label": "台南市", "value": "台南市", "Pcode": "台", "code": "台"},
      {"label": "高雄市", "value": "高雄市", "Pcode": "台", "code": "台"}
    ]
  }
];
